@@ -7,7 +7,7 @@ Usage::
     import boto3
 
     from mypy_boto3_sagemaker_a2i_runtime import AugmentedAIRuntimeClient
-    from mypy_boto3_sagemaker_a2i_runtime import (
+    from mypy_boto3_sagemaker_a2i_runtime.paginator import (
         ListHumanLoopsPaginator,
     )
 
